FMM-solver interface
This module provides a unified interface for solving BEM systems using either direct methods (TBEM) or iterative methods with FMM acceleration.
Structs
- Adaptive
Mesh Config - Adaptive mesh configuration
- CsrOperator
- CSR sparse matrix linear operator
- Dense
Operator - Dense matrix linear operator
- Diagonal
Preconditioner - Diagonal preconditioner
- Hierarchical
FmmPreconditioner - Hierarchical FMM preconditioner
- Mlfmm
Operator - MLFMM linear operator
- Slfmm
Operator - SLFMM linear operator
- Sparse
Nearfield Ilu - Sparse ILU preconditioner for FMM near-field
Functions
- estimate_
element_ count - Estimate element count for a rectangular room
- gmres_
solve_ fmm_ batched - Solves a linear system using GMRES with a batched FMM operator (unpreconditioned).
- gmres_
solve_ fmm_ batched_ with_ ilu - Solves a linear system using GMRES with a batched FMM operator and an ILU preconditioner.
- gmres_
solve_ fmm_ hierarchical - Solves a linear system using GMRES with a hierarchical FMM preconditioner.
- gmres_
solve_ tbem_ with_ ilu - Solves a TBEM system (dense matrix) using GMRES with an ILU preconditioner.
- gmres_
solve_ with_ hierarchical_ precond - Solves a linear system using GMRES with a hierarchical FMM preconditioner.
- gmres_
solve_ with_ ilu - Solves a linear system using GMRES with an ILU preconditioner derived from a dense matrix.
- gmres_
solve_ with_ ilu_ operator - Solves a linear system using GMRES with an ILU preconditioner derived from a nearfield matrix for a given operator.
- mesh_
resolution_ for_ frequency_ range - Calculate mesh resolution for a frequency range
- recommended_
mesh_ resolution - Calculate recommended mesh resolution for a given frequency
- solve_
bicgstab - Solves a linear system using the Biconjugate Gradient Stabilized (BiCGSTAB) method.
- solve_
cgs - Solves a linear system using the Conjugate Gradient Squared (CGS) method.
- solve_
gmres - Solves a linear system using the Generalized Minimum Residual (GMRES) method.
- solve_
tbem_ with_ ilu - Solve a TBEM system (dense matrix) using CGS with an ILU preconditioner.
- solve_
with_ ilu - Solves a linear system with an ILU preconditioner.
- solve_
with_ ilu_ operator - Solves a linear system with a given operator and an ILU preconditioner (placeholder, currently not used).