pub struct IluOperator { /* private fields */ }Expand description
ILU preconditioner wrapper implementing LinearOperator
This wraps the ILU preconditioner to work with the LinearOperator interface.
Implementations
Sourceimpl IluOperator
impl IluOperator
Sourcepub fn new(preconditioner: IluPreconditioner, n: usize) -> Self
pub fn new(preconditioner: IluPreconditioner, n: usize) -> Self
Create from an ILU preconditioner
Sourcepub fn from_tbem_matrix(matrix: &Array2<Complex64>) -> Self
pub fn from_tbem_matrix(matrix: &Array2<Complex64>) -> Self
Create from a dense matrix with default settings for TBEM
Sourcepub fn from_matrix(
matrix: &Array2<Complex64>,
method: IluMethod,
degree: IluScanningDegree,
) -> Self
pub fn from_matrix( matrix: &Array2<Complex64>, method: IluMethod, degree: IluScanningDegree, ) -> Self
Create from a dense matrix with specified method and degree
Sourcepub fn fill_ratio(&self) -> f64
pub fn fill_ratio(&self) -> f64
Get fill ratio (nnz(L+U) / n^2)